{#fullpage_dlg.title}

- {#fullpage_dlg.meta_tab}
- {#fullpage_dlg.appearance_tab}

{#fullpage_dlg.meta_props}

{#fullpage_dlg.meta_title} |
{#fullpage_dlg.meta_keywords} |
{#fullpage_dlg.meta_description} |
{#fullpage_dlg.author} |
{#fullpage_dlg.copyright} |
{#fullpage_dlg.meta_robots} |

{#fullpage_dlg.langprops}

{#fullpage_dlg.encoding} |
{#fullpage_dlg.doctypes} |
{#fullpage_dlg.langcode} |
{#fullpage_dlg.langdir} |
{#fullpage_dlg.xml_pi} |

{#fullpage_dlg.appearance_textprops}

{#fullpage_dlg.fontface} |
{#fullpage_dlg.fontsize} |
{#fullpage_dlg.textcolor} |

{#fullpage_dlg.appearance_bgprops}

{#fullpage_dlg.bgimage} |
{#fullpage_dlg.bgcolor} |

{#fullpage_dlg.appearance_marginprops}

{#fullpage_dlg.left_margin} |  | {#fullpage_dlg.right_margin} |
{#fullpage_dlg.top_margin} |  | {#fullpage_dlg.bottom_margin} |

{#fullpage_dlg.appearance_linkprops}

{#fullpage_dlg.link_color} |
| {#fullpage_dlg.visited_color} |
{#fullpage_dlg.active_color} |

{#fullpage_dlg.appearance_style}

{#fullpage_dlg.stylesheet} |
{#fullpage_dlg.style} |